@@ -2,7 +2,7 @@ package PAR::StrippedPARL::Base;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.975';
+our $VERSION = '0.958';
 
 use File::Temp ();
 use File::Spec;
@@ -68,11 +68,7 @@ sub write_parl {
     chmod(oct('755'), $tfile);
 
     # Use this to generate a real parl
-    my @libs = ();
-    for my $ilib ( @INC ) {
-        $ilib =~ s/\\$/\\\\/;
-        push(@libs, qq(-I\"$ilib\") );
-    }
+    my @libs = (map {"-I\"$_\""} @INC);
     my @args = (@libs, qw/-q -B/);
 
     # prepend ./ if applicable
@@ -162,7 +158,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.
+Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
